delog

package module
v0.0.0-...-f02ec89 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2022 License: MIT Imports: 13 Imported by: 0

README

Delog(debug x log) - The instant logger package for debug

.github/workflows/ci.yml Go Report Card codecov MIT License

Description

Delog provides a package for logging instantly such as dubugging and one command to remove them all.

Installation

Go
$ go install github.com/task4233/delog/cmd/delog@latest

Use Case

  • Writes delog function on Go codes for debugging and sweeps them all with $ delog clean .
  • Adds delog into pre-commit of Git

Author

task4233

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Fprintf

func Fprintf(w io.Writer, format string, v ...any) (int, error)

Fprintf formats according to a format specifier and writes to w. Arguments are handled in the manner of fmt.FPrintf.

func Fprintln

func Fprintln(w io.Writer, v ...any) (int, error)

Fprintln formats using the default formats for its operands and writes to w. Spaces are always added between operands and a newline is appended. Arguments are handled in the manner of fmt.FPrintln.

func Printf

func Printf(format string, v ...any) (int, error)

Printf calls Fprintf to print to the standard logger. Arguments are handled in the manner of fmt.Printf.

func Println

func Println(v ...any) (int, error)

Println calls Fprintln to print to the standard logger. Arguments are handled in the manner of fmt.Printf.

Types

type Delog

type Delog struct {
	// contains filtered or unexported fields
}

Delog structs

func New

func New() *Delog

New for running delog package with CLI

func (*Delog) Clean

func (c *Delog) Clean(ctx context.Context, baseDir string) error

Clean deletes all methods related to delog in ".go" files under the given directory path

func (*Delog) Run

func (c *Delog) Run(ctx context.Context, args []string) error

Run executes each method for delog package

func (Delog) Sweep

func (d Delog) Sweep(ctx context.Context, targetPath string) error

Sweep deletes all methods related to delog

Directories

Path Synopsis
cmd
delog command

Jump to